==> KarsTS_1.0.tar.gz: KarsTS/R/globalV.R <==



makeGlobal <- c("KTSEnv","CombiType", "OBErrors", "UF", "activMenu",
                "alfa", "candidToRedden", "cenday","cenhour", "cenmins",
                "cenmonth", "censecs", "cenyear", "correl", "cri1cbValue",
                "cri2cbValue", "cri3cbValue", "cri4cbValue", "cri5cbValue",
                "dSList", "degreepol","delay", "delsel", "dentro",
                "dentroplot", "depla0", "doCorrSum", "doSampEntr",
                "ele1cbValue", "ele2cbValue", "embDelays", "embDim",
                "embDimension", "embsel", "escFact",
                "extrap", "finday", "finhour", "finmins", "finmonth",
                "finsecs", "finyear", "fragToZoom",
                "frameForButtons0", "gapselec","gapselecname", "grP",
                "heigth4","indicesToRedden", "iniday", 
                "inihour", "inimins", "inimonth", "inisecs", "iniyear",
                "inpCheckedInd", "lagDel", "lagDelay", "lagDif", "lengthGap", 
                "madila", "magniTSNames","mainPanel", "mainPanel.0",
                "maxEmb", "maxIter", "maxIterations", "maxRad", "maxcbValue",
                "maxiSize", "maxniter", "mecbValue", "medcbValue",
                "mediaona", "menu1Button", "menu2Button",
                "menu3Button", "menu4Button","menu5Button",
                "minEmb", "minLength", "minRad", "mincbValue", "miniSize",
                "nDiameter","nTrees", "naDens", "naTreatment",
                "naTreatmentSel", "namesCols", "ncolPredata",
                "newName", "nnmgap", "nombre", "notAll", "nuf", "numRad",
                "numberBars", "numberGaps","origTSName",
                "numberTrees", "numlag", "outCheckedInd", "panelName",
                "parPlotSize", "peri", "period",
                "perival", "pointToFill", "predTSNames", "q1cbValue",
                "q3cbValue", "ressMeVal","rmaselec", "rmaselecname", "row1",
                "row11","row4", "row4.col1", "row4.col2", "row4.col3", "row5", 
                "rows2and3", "scaleYN","screenSize","rmFromFilling","rmFromFill",
                "sdcbValue", "seasonality", "seawin", "selNewName",
                "selgap", "selrma","selrma1", "selrma2", "selser", "selser0",
                "selser1", "selser2", "selsizeWindow", "seriesel",
                "seriesel1name", "seriesel2name", "serieselname", "sigdi0",
                "signifLev", "sizeSurr","sizeWindow", "slopeTSNames", 
                "spaceForTxtW", "spaceForTxtW5", "span", "specGap",
                "statisType", "statisTypeSel", "KTSFonts", "tailornot", 
                "theilWin", "theilerWin","thresh", "timeDelay", "timeZone",
                "tiparch", "tipo", "tkrp", "tkrp1", "tkrp2", "tkrp3",
                "touchedPoints", "trendwin", "tsPlot", "txtWidget", 
                "txtWidget5", "umbral", "uC","ventanaper", "width4.1",
                "width4.2", "widthRow1","win1", "win2", "win3", "win4", "win5","win6",
                "win7", "wingap", "xScr", "xScr5", "yScr","yScr5",
                "aboutKTSButton", "createSubPanR4C3", "helpButton", "saveReportBut",
                "selGap","selGapName", "selGapP", "selRm", "selRmName", "selRmP", 
                "selRmP1", "selRmP2", "selTs","selTs1Name", "selTs2Name", 
                "selTsName", "selTsP", "selTsP0", "selTsP1", "selTsP2","subPanR4C1",
                "tsWithGapsName","txt1","txt2","mininumNObs","selIniVal","selCenterOrNot",
                "magTs","magTsP","magTsName","dirTsP", "numberBins","numberTicks",
                "bsE","fxE","perE")


#' @import utils
utils::globalVariables(makeGlobal)

KTSEnv <- new.env()

==> KarsTS_2.0.tar.gz: KarsTS/R/globalV.R <==



makeGlobal <- c("KTSEnv","CombiType", "OBErrors", "UF", "activMenu",
                "alfa", "candidToRedden", "cenday","cenhour", "cenmins",
                "cenmonth", "censecs", "cenyear", "correl", "cri1cbValue",
                "cri2cbValue", "cri3cbValue", "cri4cbValue", "cri5cbValue",
                "dSList", "degreepol","delay", "delsel", "dentro",
                "dentroplot", "depla0", "doCorrSum", "doSampEntr",
                "lin", "poin", "embDelays", "embDim","saveToFile","xlim",
                "embDimension", "embsel", "escFact","ZInd","theScalar",
                "extrap", "finday", "finhour", "finmins", "finmonth",
                "finsecs", "finyear", "fragToZoom","fragToZooms",
                "frameForButtons0", "gapselec","gapselecname", "grP",
                "heigth4","indicesToRedden", "iniday", 
                "inihour", "inimins", "inimonth", "inisecs", "iniyear",
                "inpCheckedInd", "lagDel", "lagDelay", "lagDif", "lengthGap", 
                "madila", "magniTSNames","mainPanel", "mainPanel.0",
                "maxEmb", "maxIter", "maxIterations", "maxRad", "maxcbValue",
                "maxiSize", "maxniter", "mecbValue", "medcbValue",
                "mediaona", "menu1Button", "menu2Button",
                "menu3Button", "menu4Button","menu5Button",
                "minEmb", "minLength", "minRad", "mincbValue", "miniSize",
                "nDiameter","nTrees", "naDens", "naTreatment",
                "naTreatmentSel", "namesCols", "ncolPredata",
                "newName", "nnmgap", "nombre", "notAll", "nuf", "numRad",
                "numberBars", "numberGaps","origTSName",
                "numberTrees", "numlag", "outCheckedInd", "panelName",
                "parPlotSize", "peri", "period","nuMlag",
                "perival", "pointToFill", "predTSNames", "q1cbValue",
                "q3cbValue", "ressMeVal","rmaselec", "rmaselecname", "row1",
                "row11","row4", "row4.col1", "row4.col2", "row4.col3", "row5", 
                "rows2and3", "scaleYN","screenSize","rmFromFilling","rmFromFill",
                "sdcbValue", "seasonality", "seawin", "selNewName",
                "selgap", "selrma","selrma1", "selrma2", "selser", "selser0",
                "selser1", "selser2", "selsizeWindow", "seriesel",
                "seriesel1name", "seriesel2name", "serieselname", "sigdi0",
                "signifLev", "sizeSurr","sizeWindow", "slopeTSNames", 
                "spaceForTxtW", "spaceForTxtW5", "span", "specGap",
                "statisType", "statisTypeSel", "KTSFonts", "tailornot", 
                "theilWin", "theilerWin","thresh", "timeDelay", "timeZone",
                "tiparch", "tipo", "tkrp", "tkrp1", "tkrp2", "tkrp3",
                "touchedPoints", "trendwin", "tsPlot", "txtWidget", 
                "txtWidget5", "umbral", "uC","ventanaper", "width4.1",
                "width4.2", "widthRow1","win1", "win2", "win3", "win4", "win5","win6",
                "win7", "wingap", "xScr", "xScr5", "yScr","yScr5",
                "aboutKTSButton", "createSubPanR4C3", "helpButton", "saveReportBut",
                "selGap","selGapName", "selGapP", "selRm", "selRmName", "selRmP", 
                "selRmP1", "selRmP2", "selTs","selTs1Name", "selTs2Name", 
                "selTsName", "selTsP", "selTsP0", "selTsP1", "selTsP2","subPanR4C1",
                "tsWithGapsName","txt1","txt2","mininumNObs","selIniVal","selCenterOrNot",
                "magTs","magTsP","magTsName","dirTsP", "numberBins","numberTicks",
                "bsE","fxE","perE","lemar","lemars","lomar","lomars",
                "tsToPlotNames","lineas","puntos","lin","poin",
                "tsToPlotNamesZ","xlabs","ylabs","zlabs","tickSis","labSis","CoLoRs",
                "linWs", "poiSs","suff","newWin","filename","winW","winH",
                "xScls","yScls","CountTS","defaultTSCoLoRs","typeDist","typeDi")


#' @import utils
utils::globalVariables(makeGlobal)

KTSEnv <- new.env()
